/*                               -*- Mode: C -*- 
 * config.h.in -- 
 * 
 * $Id$
 * 
 * Copyright (c) 1991-2012 Francois Felix Ingrand.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *    - Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *    - Redistributions in binary form must reproduce the above
 *      copyright notice, this list of conditions and the following
 *      disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */

/* This one is created by autoheader and "tweaked" by configure */

#include "config-ac.h"

/* After this line... my own customization... Presumably those not taken
 * care by autoconf, or translation from autoconf to some symbol I was using
 * before...*/

/* This will do for now, but it should be set by some global configure
   parameter...  */
#define LANGUAGE ENGLISH

#ifdef HAVE_LIBREADLINE
#define HAS_READLINE
#endif

#ifdef HAVE_VALLOC
#define HAS_VALLOC
#endif

/* Has timer functions and SIGALARM. */
#ifdef HAVE_SETITIMER
#define HAS_TIMER
#endif

#ifdef HAVE_SIGACTION
#define HAS_SIGACTION
#endif


/* Has the abort function call. */
#ifdef HAVE_ABORT
#define HAS_ABORT
#endif

#ifdef WORDS_BIGENDIAN
#ifndef BIG_ENDIAN
#define BIG_ENDIAN
#endif
#else
#ifndef LITTLE_ENDIAN
#define LITTLE_ENDIAN
#endif
#endif


/* Has the fork function call. */
#ifdef HAVE_FORK
#define HAS_FORK
#endif

#define INLINE inline



/********************************************************************
 *
 * OPRS Features section. 
 *
 ********************************************************************/

/* OPRS_DEBUG ... This is a development SYMBOL... */
#undef OPRS_DEBUG

/* OPRS_PROFILING: should be set if you want a kernel with profiling
   information. */
#undef OPRS_PROFILING

/* One of the following should be defined (or it default to OPRS_MALLOC). */
/* Use standard malloc only. */
#define STD_MALLOC

/* Use a mixe of OPRS malloc and standard one.
   This is the preferred option. */
#undef MIXED_MALLOC

/* Use OPRS malloc only.  Quite good too.*/
#undef OPRS_MALLOC

#undef DEBUG_COMPACTION

/* Allow report on the malloc bucket use. */
#undef MALLOC_MOUCHARD

/* Should be used if the OP Editor must register... Should be tested though. */
#undef REGISTER_OP_EDITOR

/* This is an internal LAAS option to allow connection to IxTeT Reco. */
#undef CONNECT_TO_IXTET

/* This is a development option to find unexisting documentation node. */
#undef FIND_UNEXISTING_NODE

#undef TRUCK_DEMO

/********************************************************************
 *
 * System OS Features section.
 *
 ********************************************************************/

#undef HAS_BUFSIZ

/* Some systems do not define/initialize yyin and yyout propely.
 In this case define this variable. */
#undef YY_NO_CONST

/* If setbuf undefined, then use setbuffer. */
#undef SETBUF_UNDEFINED

/* On some systems these are undefined... */
#undef HAS_STRERROR

/* On these systems DEC, HP_UX, VXWORKS and IRIS4D, it looks like real_path
   is undefined. */
#undef REALPATH_UNDEFINED

/* SysV: pid_t setpgrp(void);
   Bsd: int setpgrp(int pid, int pgrp); */
#undef SETPGRP_TAKE_ARGS

/* Defined on Solaris 2.x etc...     */
#undef HAS_IOCTL_TIOCNOTTY

/* Self Explanatory... used by the oprs-server to have an accept thread... */
#define USE_MULTI_THREAD

#define HAS_PTHREAD_KILL

#undef HAS_GETCWD

#undef HAS_GETHOSTNAME_DECLARATION

/* Some sprint (SUN_BSD and DEC for example) returns the string, and
   not the size of the printed string. */
#undef SPRINT_RETURN_STRING

/* on HPUX this must be define... this define should be
   renamed... after understanding what it really does. */
#undef SA_SIGINFO_UNDEFINED

/* One of the two following should be defined. */
#undef HAS_LRAND48
#undef HAS_RAND

/* These are self explanatory. */
#undef HAS_BZERO
#undef HAS_BCOPY
#undef HAS_INDEX

/* Some system do not support TZP in gettimeofday 
   defined(SUN_SOLARIS) || defined(VXWORKS) */
#undef GETTIMEOFDAY_HAS_NOT_TZP

#undef SUN_BSD_BRK

#undef HAS_RLIMIT

#undef HAS_SIGSETMASK

#undef DEFINE_MEMALIGN

/* tolower does not accept all char... */
#undef HAS_TOLOWER

/* If set, should have a value.  */
#undef HAS_UNCOMPRESS

/* Has getuid system call. */
#undef HAS_GETUID

/* Has unist.h */
#undef HAS_UNISTD

/* Use WinSock (Win95) */
#undef WINSOCK

/* Has times function. */
#undef HAS_TIMES

/* has utsname.h */
#undef HAS_UTSNAME


/* has systeminfo.h */
#undef HAS_SYSTEMINFO

/********************************************************************
 *
 * System Windowing Features section.
 *
 ********************************************************************/

/* Self explanatory. */
#undef HAS_MOTIF_1_2

/* There is a bug with non Motif widget initialization in Motif 1.2
   and above. */
#undef HAS_MOTIF_CLASS_INITIALIZE_BUG

/* Motif has XmCreateTemplateDialog... This is usually true for
   motif version > 1.2 */
#undef MOTIF_HAS_TEMPLATE_DIALOG

/* Should be set if _XEditResCheckMessages() is available.
   This is usually true on X11Rx x>=5 systems. But not on HP... */
#undef XEDITRESCHECKMESSAGES_AVAILABLE

/* On some X11R5 Solaris 1, when linking statically, dlsym, dlopen and dlclose
   are undefined. This is a sun dl bug */
#undef DLSYMOPENCLOSE_UNDEFINED

/* Define this if you wan the OPE to displaya DEBUG button giving you
   acces to the mstats funciton. */
#undef OPE_ADD_MSTATS_BUTTON
